==> fltk-1.3.5-2-aarch64.pkg.tar.xz: usr/share/fltk/FLTK-Targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "fluid" for configuration "None"
set_property(TARGET fluid APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fluid PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/fluid"
  )

list(APPEND _IMPORT_CHECK_TARGETS fluid )
list(APPEND _IMPORT_CHECK_FILES_FOR_fluid "${_IMPORT_PREFIX}/bin/fluid" )

# Import target "fltk_STATIC" for configuration "None"
set_property(TARGET fltk_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "C;CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "/usr/lib/libdl.so;-lpthread;/usr/lib/libX11.so;/usr/lib/libXext.so;/usr/lib/libXfixes.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_STATIC "/usr/lib/libfltk.a" )

# Import target "fltk_forms_STATIC" for configuration "None"
set_property(TARGET fltk_forms_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_forms_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_STATIC"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_forms.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_forms_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_forms_STATIC "/usr/lib/libfltk_forms.a" )

# Import target "fltk_images_STATIC" for configuration "None"
set_property(TARGET fltk_images_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_images_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_STATIC;/usr/lib/libjpeg.so;/usr/lib/libz.so;/usr/lib/libpng.so;/usr/lib/libz.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_images.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_images_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_images_STATIC "/usr/lib/libfltk_images.a" )

# Import target "fltk_gl_STATIC" for configuration "None"
set_property(TARGET fltk_gl_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_gl_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_STATIC;/usr/lib/libGL.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_gl.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_gl_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_gl_STATIC "/usr/lib/libfltk_gl.a" )

# Import target "fltk_SHARED" for configuration "None"
set_property(TARGET fltk_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_SHARED PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "/usr/lib/libdl.so;-lpthread;/usr/lib/libX11.so;/usr/lib/libXext.so;/usr/lib/libXfixes.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk.so.1.3.5"
  IMPORTED_SONAME_NONE "libfltk.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_SHARED "/usr/lib/libfltk.so.1.3.5" )

# Import target "fltk_forms_SHARED" for configuration "None"
set_property(TARGET fltk_forms_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_forms_SHARED PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_SHARED"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_forms.so.1.3.5"
  IMPORTED_SONAME_NONE "libfltk_forms.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_forms_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_forms_SHARED "/usr/lib/libfltk_forms.so.1.3.5" )

# Import target "fltk_images_SHARED" for configuration "None"
set_property(TARGET fltk_images_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_images_SHARED PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_SHARED;/usr/lib/libjpeg.so;/usr/lib/libpng.so;/usr/lib/libz.so;/usr/lib/libz.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_images.so.1.3.5"
  IMPORTED_SONAME_NONE "libfltk_images.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_images_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_images_SHARED "/usr/lib/libfltk_images.so.1.3.5" )

# Import target "fltk_gl_SHARED" for configuration "None"
set_property(TARGET fltk_gl_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_gl_SHARED PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_SHARED;/usr/lib/libGL.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_gl.so.1.3.5"
  IMPORTED_SONAME_NONE "libfltk_gl.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_gl_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_gl_SHARED "/usr/lib/libfltk_gl.so.1.3.5" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> fltk-1.3.5-3-aarch64.pkg.tar.xz: usr/share/fltk/FLTK-Targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "fluid" for configuration "None"
set_property(TARGET fluid APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fluid PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/fluid"
  )

list(APPEND _IMPORT_CHECK_TARGETS fluid )
list(APPEND _IMPORT_CHECK_FILES_FOR_fluid "${_IMPORT_PREFIX}/bin/fluid" )

# Import target "fltk_STATIC" for configuration "None"
set_property(TARGET fltk_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "C;CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "/usr/lib/libdl.so;-lpthread;/usr/lib/libX11.so;/usr/lib/libXext.so;/usr/lib/libXfixes.so;/usr/lib/libXrender.so;/usr/lib/libXft.so;/usr/lib/libfontconfig.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_STATIC "/usr/lib/libfltk.a" )

# Import target "fltk_forms_STATIC" for configuration "None"
set_property(TARGET fltk_forms_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_forms_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_STATIC"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_forms.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_forms_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_forms_STATIC "/usr/lib/libfltk_forms.a" )

# Import target "fltk_images_STATIC" for configuration "None"
set_property(TARGET fltk_images_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_images_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_STATIC;/usr/lib/libjpeg.so;/usr/lib/libz.so;/usr/lib/libpng.so;/usr/lib/libz.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_images.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_images_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_images_STATIC "/usr/lib/libfltk_images.a" )

# Import target "fltk_gl_STATIC" for configuration "None"
set_property(TARGET fltk_gl_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_gl_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_STATIC;/usr/lib/libGL.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_gl.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_gl_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_gl_STATIC "/usr/lib/libfltk_gl.a" )

# Import target "fltk_SHARED" for configuration "None"
set_property(TARGET fltk_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_SHARED PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "/usr/lib/libdl.so;-lpthread;/usr/lib/libX11.so;/usr/lib/libXext.so;/usr/lib/libXfixes.so;/usr/lib/libXrender.so;/usr/lib/libXft.so;/usr/lib/libfontconfig.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk.so.1.3.5"
  IMPORTED_SONAME_NONE "libfltk.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_SHARED "/usr/lib/libfltk.so.1.3.5" )

# Import target "fltk_forms_SHARED" for configuration "None"
set_property(TARGET fltk_forms_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_forms_SHARED PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_SHARED"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_forms.so.1.3.5"
  IMPORTED_SONAME_NONE "libfltk_forms.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_forms_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_forms_SHARED "/usr/lib/libfltk_forms.so.1.3.5" )

# Import target "fltk_images_SHARED" for configuration "None"
set_property(TARGET fltk_images_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_images_SHARED PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_SHARED;/usr/lib/libjpeg.so;/usr/lib/libpng.so;/usr/lib/libz.so;/usr/lib/libz.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_images.so.1.3.5"
  IMPORTED_SONAME_NONE "libfltk_images.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_images_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_images_SHARED "/usr/lib/libfltk_images.so.1.3.5" )

# Import target "fltk_gl_SHARED" for configuration "None"
set_property(TARGET fltk_gl_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_gl_SHARED PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "fltk_SHARED;/usr/lib/libGL.so"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_gl.so.1.3.5"
  IMPORTED_SONAME_NONE "libfltk_gl.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_gl_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_gl_SHARED "/usr/lib/libfltk_gl.so.1.3.5" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
